@@ -163,7 +163,7 @@ static NSString *redirectURISafetySuffix = nil;
     return _traversalPath;
   
   for (i = 0; i < count; i++) {
-    NSString *key;
+    NSString *key, *previous_key;
     unsigned klen;
     NSString *m;
     
@@ -175,7 +175,11 @@ static NSString *redirectURISafetySuffix = nil;
     /* calculate method name */
     
     m = nil;
-    if (klen == 3 && [key isEqualToString:@"Cmd"]) {
+    if([_traversalPath count] > 0)
+      previous_key = [_traversalPath lastObject];
+    else
+      previous_key = @"";
+    if (klen == 3 && [key isEqualToString:@"Cmd"] && ![previous_key isEqualToString:@"Microsoft-Server-ActiveSync"]) {
       /* 
 	 Check for ASP style ?Cmd query parameter (required in ZideStore),
 	 the value is the additional path we need to add.
