@@ -271,7 +271,7 @@ static NSException *_makeException(NSException *_exception,
   [ui setObject:[NumberClass numberWithInt:_idx]     forKey:@"position"];
 
   if (!atEof && (_idx > 0)) {
-    register unsigned pos;
+    NSInteger pos;
     const unichar *startPos, *endPos;
 
     for (pos = _idx; (pos >= 0) && (_buffer[pos] != '\n'); pos--)
