@@ -108,6 +108,8 @@ static WOMessageProfileInfo profiletot = { 0, 0, 0, 0, 0 };
   [self->content  release];
   [self->header   release];
   [self->userInfo release];
+  if (self->contentFileHandle != nil)
+     [self->contentFileHandle release];
   [super dealloc];
 }
 
@@ -356,6 +358,17 @@ static WOMessageProfileInfo profiletot = { 0, 0, 0, 0, 0 };
   return self->contentEncoding;
 }
 
+- (void)setContentFile:(NSFileHandle *) handle {
+  if (self->contentFileHandle)
+     [self->contentFileHandle release];
+  self->contentFileHandle = handle;
+  [handle retain];
+}
+
+- (NSFileHandle *)contentFile {
+  return self->contentFileHandle;
+}
+
 /* structured content */
 
 - (void)appendContentBytes:(const void *)_bytes length:(unsigned)_l {
